@@ -1,5 +1,6 @@
 package Carmel::Runner;
 use strict;
+use warnings;
 
 our $UseSystem = 0;
 
@@ -14,15 +15,21 @@ sub new {
     if ($@ && $@ =~ /Can't locate \.carmel\/MyBootstrap\.pm/) {
         die "Could not locate .carmel/MyBootstrap.pm. You need to run `carmel install` first.\n";
     }
-        
+
+    if (-d 'local' && -e 'local/lib/perl5/MyBootstrap.pm') {
+        Carmel::Runtime->environment->{local} = Carmel::Runtime->environment->{base} . '/local';
+    }
+
     bless {}, $class;
 }
 
 # Note: can't capture carmel exec perl -MModule because it's loaded earlier than PERL5OPT
 sub env {
+    my %env = Carmel::Runtime->bootstrap_env;
     return (
-        _join(PATH => Carmel::Runtime->path),
-        PERL5OPT => "-Mlib=" . Carmel::Runtime->base . " -MMyBootstrap",
+        _join(':', PATH => $env{PATH}),
+        _join(':', PERL5LIB => $env{PERL5LIB}),
+        _join(' ', PERL5OPT => $env{PERL5OPT}),
     );
 }
 
@@ -33,10 +40,10 @@ sub execute {
 }
 
 sub _join {
-    my($env, @list) = @_;
-    push @list, $ENV{$env} if $ENV{$env};
-    return ($env => join(":", @list));
+    my($sep, $env, $list) = @_;
+    return unless $list;
+    push @$list, $ENV{$env} if $ENV{$env};
+    return ($env => join($sep, @$list));
 }
 
 1;
-
